-- -------------------------------------------------------------------------- --
--                            DrainSouler by kunda                            --
-- -------------------------------------------------------------------------- --
--                                                                            --
-- Shows a small movable frame with all data you need to know for Drain Soul. --
--                                                                            --
-- Framesize: 80x20px                                                         --
-- Elements:                                                                  --
--  - HP (in percent)                                                         --
--  - Icon (visible if target HP is below 25%)                                --
--  - TickTimer (a progress bar that indicates when the next Drain Soul Tick  --
--              is expected)                                                  --
--  - Tick (the number of damage ticks since caststart)                       --
--  - DMG (Drain Soul damage from last tick)                                  --
--  - TickSound (plays a sound when Drain Soul dealt damage)                  --
-- Configuration:                                                             --
--  - If you log in the first time the 'Configuration Mode' is enabled!       --
--    Click 'Close Configuration' to finish.                                  --
--  - 'ESC -> Interface -> AddOns -> DrainSouler' to change options!          --
--                                                                            --
-- TRICKY TICK:                                                               --
--  Start Drain Soul if target HP is below 25%!                               --
--  Stop channeling Drain Soul after 4 ticks (unless you need shards)!        --
--  Drain Soul mostly does not deal 5 times damage! Stop and cast it again.   --
--  In most situations you need to reapply DoTs earlier (second or third      --
--  tick). Reapply them after a Drain Soul Tick!                              --
--                                                                            --
-- -------------------------------------------------------------------------- --

-- -------------------------------------------------------------------------- --
--                                    STOP                                    --
--                 You must be a Warlock to enter this code.                  --
--                  If you are not a Warlock please leave.                    --
        if select(2, UnitClass("player")) ~= "WARLOCK" then return end          
-- -------------------------------------------------------------------------- --

-- ---------------------------------------------------------------------------------------------------------------------
DrainSouler_Options = {}

local DrainSouler = CreateFrame("Frame")
local L = DrainSouler_Locales

local _G              = _G
local GetTime         = _G.GetTime
local UnitHealth      = _G.UnitHealth
local UnitHealthMax   = _G.UnitHealthMax
local UnitChannelInfo = _G.UnitChannelInfo
local math_floor      = _G.math.floor

local mult2 = 10^(2 or 0)
local inCombat
local PlayerGUID
local DrainSoulName, _, DrainSoulIcon = GetSpellInfo(1120)

local numTicks = 5
local DrainSoulCurrentDuration
local DrainSoulCurrentStart
local DrainSoulCurrentTick = 0
local DrainSoulIsActive

local info = {}
local sounds = {
	[1] = {name = L["No Sound"]},
	[2] = {name = "Beep1 (0.076)",  path = "Interface\\Addons\\DrainSouler\\sound_beep1.wav"},
	[3] = {name = "Beep2 (0.043)",  path = "Interface\\Addons\\DrainSouler\\sound_beep2.wav"},
	[4] = {name = "Beep3 (0.104)",  path = "Interface\\Addons\\DrainSouler\\sound_beep3.wav"},
	[5] = {name = "Deek (0.069)",   path = "Interface\\Addons\\DrainSouler\\sound_deek.wav"},
	[6] = {name = "Bump (0.134)",   path = "Interface\\Addons\\DrainSouler\\sound_bump.wav"},
	[7] = {name = "Phaser (0.162)", path = "Interface\\Addons\\DrainSouler\\sound_phaser.wav"},
	[8] = {name = "Space (0.471)",  path = "Interface\\Addons\\DrainSouler\\sound_space.wav"}
}

-----------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
local function CheckHealth()
	local maxHealth = UnitHealthMax("target")
	if maxHealth < DrainSouler_Options.minHP then
		DrainSouler_Frame:Hide()
		return
	end
	local health = UnitHealth("target") / maxHealth * 100
	if health > 0 and health <= DrainSouler_Options.minHPP then
		DrainSouler_Frame:Show()
		DrainSouler_Text_HP:SetText( math_floor(health * mult2 + 0.5) / mult2.."%" )
		if health < 25 then
			DrainSouler_Button_Icon:Show()
		else
			DrainSouler_Button_Icon:Hide()
		end
	else
		DrainSouler_Frame:Hide()
		DrainSouler_Text_HP:SetText("")
		DrainSouler_Text_DMG:SetText("")
		DrainSouler_Text_Tick:SetText("")
	end
	if not DrainSoulIsActive then
		DrainSouler_Button_TickTimer:Hide()
	end
end

local function TargetUnitCheck()
	if not inCombat and DrainSouler_Options.onlyInCombat then
		DrainSouler_Frame:Hide()
		DrainSouler:UnregisterEvent("UNIT_HEALTH")
		return
	end

	if UnitExists("target") then
		CheckHealth()
		if DrainSouler_Frame:IsShown() then
			DrainSouler:RegisterEvent("UNIT_HEALTH")
		end
	else
		DrainSouler_Frame:Hide()
		DrainSouler:UnregisterEvent("UNIT_HEALTH")
	end
end

local function TickTimer()
	local width = 60 - (( (GetTime()*1000) - DrainSoulCurrentStart)*60) / (DrainSoulCurrentDuration/ (numTicks-DrainSoulCurrentTick) )
	if width < 0.01 then
		width = 0.01
	end
	DrainSouler_Texture_TickTimer:SetWidth(width)
end

local function OnMouseDown()
	DrainSouler_Frame:StartMoving()
end

local function OnMouseUp()
	DrainSouler_Frame:StopMovingOrSizing()
	DrainSouler_Options.posX = DrainSouler_Frame:GetLeft()
	DrainSouler_Options.posY = DrainSouler_Frame:GetTop()
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:InitOptions()
	if DrainSouler_Options.version      == nil then DrainSouler_Options.version      = 1 end
	if DrainSouler_Options.configMode   == nil then DrainSouler_Options.configMode   = true end
	if DrainSouler_Options.Lock         == nil then DrainSouler_Options.Lock         = false end
	if DrainSouler_Options.Size         == nil then DrainSouler_Options.Size         = 1 end
	if DrainSouler_Options.Alpha        == nil then DrainSouler_Options.Alpha        = 1 end
	if DrainSouler_Options.onlyInCombat == nil then DrainSouler_Options.onlyInCombat = true end
	if DrainSouler_Options.minHP        == nil then DrainSouler_Options.minHP        = 0 end
	if DrainSouler_Options.minHPP       == nil then DrainSouler_Options.minHPP       = 100 end
	if DrainSouler_Options.TickSound    == nil then DrainSouler_Options.TickSound    = 1 end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:CreateInterfaceOptions()
	local options = CreateFrame("Frame", "DrainSouler_InterfaceOptions")
	options.name = "DrainSouler"
	DrainSouler:CreateOptions(1)
	InterfaceOptions_AddCategory(options)
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:CreateOptions(OptionType)
	local framename = "DrainSouler_ConfigModeOptions"
	if OptionType == 1 then
		framename = "DrainSouler_InterfaceOptions"
	end
	local frame = _G[framename]

	-- Title
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	if OptionType == 1 then
		title:SetText("DrainSouler")
	else
		title:SetText("DrainSouler ("..L["Configuration Mode"]..")")
	end
	title:SetJustifyH("LEFT")
	title:SetJustifyV("TOP")

	-- Configuration Mode
	if OptionType == 1 then
		CreateFrame("Button", framename.."_ConfigMode", frame, "UIPanelButtonTemplate2")
		_G[framename.."_ConfigMode"]:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -10)
		_G[framename.."_ConfigMode"]:SetWidth(120)
		_G[framename.."_ConfigMode"]:SetHeight(24)
		_G[framename.."_ConfigModeText"]:SetText(L["Enable Configuration Mode"])
		_G[framename.."_ConfigMode"]:SetWidth( _G[framename.."_ConfigModeText"]:GetStringWidth()+25 )
		_G[framename.."_ConfigMode"]:SetScript("OnClick", function(self)
			InterfaceOptionsFrame_Show()
			HideUIPanel(GameMenuFrame)
			DrainSouler_Options.configMode = true
			DrainSouler:EnableConfigMode()
		end)
	end

	-- Move Note
	if OptionType == 2 then
		frame:CreateFontString(framename.."_MoveNote", "OVERLAY", "GameFontWhiteSmall")
		_G[framename.."_MoveNote"]:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -5)
		_G[framename.."_MoveNote"]:SetJustifyH("LEFT")
		_G[framename.."_MoveNote"]:SetText(L["Click and Drag on DrainSouler Frame to move it."])
		_G[framename.."_MoveNote"]:SetTextColor(1, 1, 0.5, 1)
	end

	-- onlyInCombat
	CreateFrame("CheckButton", framename.."_onlyInCombat", frame, "InterfaceOptionsCheckButtonTemplate")
	if OptionType == 1 then
		_G[framename.."_onlyInCombat"]:SetPoint("TOPLEFT", framename.."_ConfigMode", "BOTTOMLEFT", -3, -10)
	else
		_G[framename.."_onlyInCombat"]:SetPoint("TOPLEFT", framename.."_MoveNote", "BOTTOMLEFT", -3, -10)
	end
	_G[framename.."_onlyInCombatText"]:SetText(L["Show DrainSouler only in combat"])
	_G[framename.."_onlyInCombat"]:SetChecked(DrainSouler_Options.onlyInCombat)

	-- Lock
	local Lock = CreateFrame("CheckButton", framename.."_Lock", frame, "InterfaceOptionsCheckButtonTemplate")
	_G[framename.."_Lock"]:SetPoint("TOPLEFT", framename.."_onlyInCombat", "BOTTOMLEFT", 0, 0)
	_G[framename.."_LockText"]:SetText(L["Lock DrainSouler"])
	_G[framename.."_Lock"]:SetChecked(DrainSouler_Options.Lock)

	-- Size
	local Size = CreateFrame("Slider", framename.."_Size", frame, "OptionsSliderTemplate")
	_G[framename.."_Size"]:SetWidth(150)
	_G[framename.."_Size"]:SetHeight(16)
	_G[framename.."_Size"]:SetPoint("TOPLEFT", framename.."_Lock", "BOTTOMLEFT", 6, -20)
	_G[framename.."_SizeText"]:SetPoint("LEFT")
	_G[framename.."_SizeText"]:SetText( string.format(L["Size: %s"], "|cffffff99"..DrainSouler_Options.Size.."|r") )
	_G[framename.."_SizeText"]:SetJustifyH("LEFT")
	_G[framename.."_SizeLow"]:SetPoint("TOPLEFT", Size, "BOTTOMLEFT", 2, 3)
	_G[framename.."_SizeLow"]:SetText("0.50")
	_G[framename.."_SizeHigh"]:SetPoint("TOPRIGHT", Size, "BOTTOMRIGHT", -2, 3)
	_G[framename.."_SizeHigh"]:SetText("1.5")
	_G[framename.."_Size"]:SetMinMaxValues(50, 150)
	_G[framename.."_Size"]:SetValueStep(5)
	_G[framename.."_Size"]:SetValue(DrainSouler_Options.Size*100)

	-- Alpha
	local Alpha = CreateFrame("Slider", framename.."_Alpha", frame, "OptionsSliderTemplate")
	_G[framename.."_Alpha"]:SetWidth(150)
	_G[framename.."_Alpha"]:SetHeight(16)
	_G[framename.."_Alpha"]:SetPoint("TOPLEFT", framename.."_Size", "TOPRIGHT", 20, 0)
	_G[framename.."_AlphaText"]:SetPoint("LEFT")
	_G[framename.."_AlphaText"]:SetText( string.format(L["Alpha (Transparency): %s"], "|cffffff99"..DrainSouler_Options.Alpha.."|r") )
	_G[framename.."_AlphaText"]:SetJustifyH("LEFT")
	_G[framename.."_AlphaLow"]:SetPoint("TOPLEFT", Alpha, "BOTTOMLEFT", 2, 3)
	_G[framename.."_AlphaLow"]:SetText("0.1")
	_G[framename.."_AlphaHigh"]:SetPoint("TOPRIGHT", Alpha, "BOTTOMRIGHT", -2, 3)
	_G[framename.."_AlphaHigh"]:SetText("1")
	_G[framename.."_Alpha"]:SetMinMaxValues(10, 100)
	_G[framename.."_Alpha"]:SetValueStep(10)
	_G[framename.."_Alpha"]:SetValue(DrainSouler_Options.Alpha*100)

	-- minHP
	local minHP = CreateFrame("Slider", framename.."_minHP", frame, "OptionsSliderTemplate")
	_G[framename.."_minHP"]:SetWidth(200)
	_G[framename.."_minHP"]:SetHeight(16)
	_G[framename.."_minHP"]:SetPoint("TOPLEFT", framename.."_Size", "BOTTOMLEFT", 0, -40)
	_G[framename.."_minHPText"]:SetPoint("LEFT")
	_G[framename.."_minHPText"]:SetText( string.format(L["Target HP: %s"], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
	_G[framename.."_minHPText"]:SetJustifyH("LEFT")
	_G[framename.."_minHPLow"]:SetPoint("TOPLEFT", minHP, "BOTTOMLEFT", 2, 3)
	_G[framename.."_minHPLow"]:SetText("0")
	_G[framename.."_minHPHigh"]:SetPoint("TOPRIGHT", minHP, "BOTTOMRIGHT", -2, 3)
	_G[framename.."_minHPHigh"]:SetText("250000")
	_G[framename.."_minHP"]:SetMinMaxValues(0, 250000)
	_G[framename.."_minHP"]:SetValueStep(5000)
	_G[framename.."_minHP"]:SetValue(DrainSouler_Options.minHP)

	_G[framename.."_minHP"]:CreateFontString(framename.."_minHP_description", "OVERLAY", "GameFontWhiteSmall")
	_G[framename.."_minHP_description"]:SetPoint("TOPLEFT", minHP, "BOTTOMLEFT", 0, -15)
	_G[framename.."_minHP_description"]:SetJustifyH("LEFT")
	_G[framename.."_minHP_description"]:SetText( string.format(L["Shows DrainSouler if maximum target HP is greater than %s."], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
	_G[framename.."_minHP_description"]:SetTextColor(0.6, 0.6, 0.6, 1)

	-- minHPP
	local minHPP = CreateFrame("Slider", framename.."_minHPP", frame, "OptionsSliderTemplate")
	_G[framename.."_minHPP"]:SetWidth(200)
	_G[framename.."_minHPP"]:SetHeight(16)
	_G[framename.."_minHPP"]:SetPoint("TOPLEFT", framename.."_minHP_description", "BOTTOMLEFT", 0, -30)
	_G[framename.."_minHPPText"]:SetPoint("LEFT")
	_G[framename.."_minHPPText"]:SetText( string.format(L["Target HP (in percent): %s"], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
	_G[framename.."_minHPPText"]:SetJustifyH("LEFT")
	_G[framename.."_minHPPLow"]:SetPoint("TOPLEFT", minHPP, "BOTTOMLEFT", 2, 3)
	_G[framename.."_minHPPLow"]:SetText("25%")
	_G[framename.."_minHPPHigh"]:SetPoint("TOPRIGHT", minHPP, "BOTTOMRIGHT", -2, 3)
	_G[framename.."_minHPPHigh"]:SetText("100%")
	_G[framename.."_minHPP"]:SetMinMaxValues(25, 100)
	_G[framename.."_minHPP"]:SetValueStep(5)
	_G[framename.."_minHPP"]:SetValue(DrainSouler_Options.minHPP)

	_G[framename.."_minHPP"]:CreateFontString(framename.."_minHPP_description", "OVERLAY", "GameFontWhiteSmall")
	_G[framename.."_minHPP_description"]:SetPoint("TOPLEFT", minHPP, "BOTTOMLEFT", 0, -15)
	_G[framename.."_minHPP_description"]:SetJustifyH("LEFT")
	_G[framename.."_minHPP_description"]:SetText( string.format(L["Shows DrainSouler if target HP (in percent) is less or equal %s."], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
	_G[framename.."_minHPP_description"]:SetTextColor(0.6, 0.6, 0.6, 1)

	-- TickSound
	local TickSound = CreateFrame("Frame", framename.."_TickSound", frame, "UIDropDownMenuTemplate")
	_G[framename.."_TickSound"]:SetPoint("TOPLEFT", framename.."_minHPP_description", "BOTTOMLEFT", -16, -34)
	_G[framename.."_TickSound"]:CreateFontString(framename.."_TickSound_title", "BACKGROUND", "GameFontHighlight")
	_G[framename.."_TickSound_title"]:SetPoint("BOTTOMLEFT", TickSound, "TOPLEFT", 16, 5)
	_G[framename.."_TickSound_title"]:SetText(L["TickSound"]..":")

	_G[framename.."_TickSound"]:CreateFontString(framename.."_TickSound_description", "OVERLAY", "GameFontWhiteSmall")
	_G[framename.."_TickSound_description"]:SetPoint("TOPLEFT", TickSound, "BOTTOMLEFT", 16, 0)
	_G[framename.."_TickSound_description"]:SetJustifyH("LEFT")
	_G[framename.."_TickSound_description"]:SetText(L["Plays a sound when Drain Soul dealt damage."])
	_G[framename.."_TickSound_description"]:SetTextColor(0.6, 0.6, 0.6, 1)

	-- Close Configuration
	if OptionType == 2 then
		local closeconfig = CreateFrame("Button", framename.."_CloseConfiguration", frame, "UIPanelButtonTemplate2")
		_G[framename.."_CloseConfiguration"]:SetPoint("TOPLEFT", framename.."_TickSound_description", "BOTTOMLEFT", -3, -20)
		_G[framename.."_CloseConfiguration"]:SetWidth(120)
		_G[framename.."_CloseConfiguration"]:SetHeight(24)
		_G[framename.."_CloseConfigurationText"]:SetText(L["Close Configuration"])
		_G[framename.."_CloseConfiguration"]:SetWidth( _G[framename.."_CloseConfigurationText"]:GetStringWidth()+25 )
		_G[framename.."_CloseConfiguration"]:SetScript("OnClick", function(self)
			DrainSouler_Options.configMode = false
			DrainSouler:DisableConfigMode()
		end)

		_G[framename.."_CloseConfiguration"]:CreateFontString(framename.."_CloseConfiguration_description", "OVERLAY", "GameFontWhiteSmall")
		_G[framename.."_CloseConfiguration_description"]:SetPoint("TOPLEFT", closeconfig, "BOTTOMLEFT", 3, -5)
		_G[framename.."_CloseConfiguration_description"]:SetJustifyH("LEFT")
		_G[framename.."_CloseConfiguration_description"]:SetText(L["'ESC -> Interface -> AddOns -> DrainSouler' to change Options!"])
		_G[framename.."_CloseConfiguration_description"]:SetTextColor(1, 1, 0.5, 1)
	end
end

function DrainSouler:CreateOptions_SetupScripts()
	-- onlyInCombat
	DrainSouler_ConfigModeOptions_onlyInCombat:SetScript("OnClick", function(self)
		DrainSouler_Options.onlyInCombat = not DrainSouler_Options.onlyInCombat
		DrainSouler_InterfaceOptions_onlyInCombat:SetChecked(DrainSouler_Options.onlyInCombat)
		if not DrainSouler_ConfigModeOptions:IsShown() then
			TargetUnitCheck()
		end
	end)
	DrainSouler_InterfaceOptions_onlyInCombat:SetScript("OnClick", function(self)
		DrainSouler_Options.onlyInCombat = not DrainSouler_Options.onlyInCombat
		DrainSouler_ConfigModeOptions_onlyInCombat:SetChecked(DrainSouler_Options.onlyInCombat)
		if not DrainSouler_ConfigModeOptions:IsShown() then
			TargetUnitCheck()
		end
	end)

	-- Lock
	DrainSouler_ConfigModeOptions_Lock:SetScript("OnClick", function(self)
		DrainSouler_Options.Lock = not DrainSouler_Options.Lock
		DrainSouler_InterfaceOptions_Lock:SetChecked(DrainSouler_Options.Lock)
		if DrainSouler_Options.Lock then
			DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(0, 0, 0, 1)
			DrainSouler:DisableMovement()
		else
			DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(1, 1, 0.5, 1)
			DrainSouler:EnableMovement()
		end
	end)
	DrainSouler_InterfaceOptions_Lock:SetScript("OnClick", function(self)
		DrainSouler_Options.Lock = not DrainSouler_Options.Lock
		DrainSouler_ConfigModeOptions_Lock:SetChecked(DrainSouler_Options.Lock)
		if DrainSouler_Options.Lock then
			DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(0, 0, 0, 1)
			DrainSouler:DisableMovement()
		else
			DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(1, 1, 0.5, 1)
			DrainSouler:EnableMovement()
		end
	end)

	-- Alpha
	DrainSouler_ConfigModeOptions_Alpha:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.Alpha = value/100
		DrainSouler_InterfaceOptions_Alpha:SetValue(DrainSouler_Options.Alpha*100)
		DrainSouler_InterfaceOptions_AlphaText:SetText( string.format(L["Alpha (Transparency): %s"], "|cffffff99"..DrainSouler_Options.Alpha.."|r") )
		DrainSouler_ConfigModeOptions_AlphaText:SetText( string.format(L["Alpha (Transparency): %s"], "|cffffff99"..DrainSouler_Options.Alpha.."|r") )
		DrainSouler:SetupAlpha()
	end)
	DrainSouler_InterfaceOptions_Alpha:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.Alpha = value/100
		DrainSouler_ConfigModeOptions_Alpha:SetValue(DrainSouler_Options.Alpha*100)
		DrainSouler_InterfaceOptions_AlphaText:SetText( string.format(L["Alpha (Transparency): %s"], "|cffffff99"..DrainSouler_Options.Alpha.."|r") )
		DrainSouler_ConfigModeOptions_AlphaText:SetText( string.format(L["Alpha (Transparency): %s"], "|cffffff99"..DrainSouler_Options.Alpha.."|r") )
		DrainSouler:SetupAlpha()
	end)

	-- Size
	DrainSouler_ConfigModeOptions_Size:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.Size = value/100
		DrainSouler_InterfaceOptions_Size:SetValue(DrainSouler_Options.Size*100)
		DrainSouler_InterfaceOptions_SizeText:SetText( string.format(L["Size: %s"], "|cffffff99"..DrainSouler_Options.Size.."|r") )
		DrainSouler_ConfigModeOptions_SizeText:SetText( string.format(L["Size: %s"], "|cffffff99"..DrainSouler_Options.Size.."|r") )
		DrainSouler:SetupSize()
	end)
	DrainSouler_InterfaceOptions_Size:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.Size = value/100
		DrainSouler_ConfigModeOptions_Size:SetValue(DrainSouler_Options.Size*100)
		DrainSouler_InterfaceOptions_SizeText:SetText( string.format(L["Size: %s"], "|cffffff99"..DrainSouler_Options.Size.."|r") )
		DrainSouler_ConfigModeOptions_SizeText:SetText( string.format(L["Size: %s"], "|cffffff99"..DrainSouler_Options.Size.."|r") )
		DrainSouler:SetupSize()
	end)

	-- minHP
	DrainSouler_ConfigModeOptions_minHP:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.minHP = value
		DrainSouler_InterfaceOptions_minHP:SetValue(DrainSouler_Options.minHP)
		DrainSouler_InterfaceOptions_minHP_description:SetText( string.format(L["Shows DrainSouler if maximum target HP is greater than %s."], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_InterfaceOptions_minHPText:SetText( string.format(L["Target HP: %s"], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_ConfigModeOptions_minHP_description:SetText( string.format(L["Shows DrainSouler if maximum target HP is greater than %s."], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_ConfigModeOptions_minHPText:SetText( string.format(L["Target HP: %s"], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
	end)
	DrainSouler_InterfaceOptions_minHP:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.minHP = value
		DrainSouler_ConfigModeOptions_minHP:SetValue(DrainSouler_Options.minHP)
		DrainSouler_InterfaceOptions_minHP_description:SetText( string.format(L["Shows DrainSouler if maximum target HP is greater than %s."], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_InterfaceOptions_minHPText:SetText( string.format(L["Target HP: %s"], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_ConfigModeOptions_minHP_description:SetText( string.format(L["Shows DrainSouler if maximum target HP is greater than %s."], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
		DrainSouler_ConfigModeOptions_minHPText:SetText( string.format(L["Target HP: %s"], "|cffffff99"..DrainSouler_Options.minHP.."|r") )
	end)

	-- minHPP
	DrainSouler_ConfigModeOptions_minHPP:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.minHPP = value
		DrainSouler_InterfaceOptions_minHPP:SetValue(DrainSouler_Options.minHPP)
		DrainSouler_InterfaceOptions_minHPP_description:SetText( string.format(L["Shows DrainSouler if target HP (in percent) is less or equal %s."], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_InterfaceOptions_minHPPText:SetText( string.format(L["Target HP (in percent): %s"], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_ConfigModeOptions_minHPP_description:SetText( string.format(L["Shows DrainSouler if target HP (in percent) is less or equal %s."], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_ConfigModeOptions_minHPPText:SetText( string.format(L["Target HP (in percent): %s"], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
	end)
	DrainSouler_InterfaceOptions_minHPP:SetScript("OnValueChanged", function(self, value)
		DrainSouler_Options.minHPP = value
		DrainSouler_ConfigModeOptions_minHPP:SetValue(DrainSouler_Options.minHPP)
		DrainSouler_InterfaceOptions_minHPP_description:SetText( string.format(L["Shows DrainSouler if target HP (in percent) is less or equal %s."], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_InterfaceOptions_minHPPText:SetText( string.format(L["Target HP (in percent): %s"], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_ConfigModeOptions_minHPP_description:SetText( string.format(L["Shows DrainSouler if target HP (in percent) is less or equal %s."], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
		DrainSouler_ConfigModeOptions_minHPPText:SetText( string.format(L["Target HP (in percent): %s"], "|cffffff99"..DrainSouler_Options.minHPP.."%|r") )
	end)

	-- TickSound
	local width = 0
	for i=1, #sounds do
		DrainSouler_ConfigModeOptions_TickSoundText:SetText(sounds[i].name)
		local twidth = DrainSouler_ConfigModeOptions_TickSoundText:GetWidth()
		if twidth > width then
			width = twidth
		end
	end

	DrainSouler_ConfigModeOptions_TickSound.initialize = function()
		for i=1, #sounds do
			info.text = sounds[i].name
			info.arg1 = i
			info.arg2 = nil
			info.func = function(button, selected)
				DrainSouler_Options.TickSound = selected
				DrainSouler_ConfigModeOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)

				DrainSouler_InterfaceOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)
				
				UIDropDownMenu_SetWidth(DrainSouler_ConfigModeOptions_TickSound, width+50)
				if DrainSouler_Options.TickSound > 1 then
					PlaySoundFile(sounds[DrainSouler_Options.TickSound].path)
				end
			end
			if DrainSouler_Options.TickSound == info.arg1 then
				info.checked = 1
			else
				info.checked = nil
			end
			info.keepShownOnClick = nil
			UIDropDownMenu_AddButton(info)
		end
	end
	DrainSouler_ConfigModeOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)
	UIDropDownMenu_SetWidth(DrainSouler_ConfigModeOptions_TickSound, width+50)
	UIDropDownMenu_EnableDropDown(DrainSouler_ConfigModeOptions_TickSound)

	DrainSouler_InterfaceOptions_TickSound.initialize = function()
		for i=1, #sounds do
			info.text = sounds[i].name
			info.arg1 = i
			info.arg2 = nil
			info.func = function(button, selected)
				DrainSouler_Options.TickSound = selected
				DrainSouler_InterfaceOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)
				
				DrainSouler_ConfigModeOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)
				
				UIDropDownMenu_SetWidth(DrainSouler_InterfaceOptions_TickSound, width+50)
				if DrainSouler_Options.TickSound > 1 then
					PlaySoundFile(sounds[DrainSouler_Options.TickSound].path)
				end
			end
			if DrainSouler_Options.TickSound == info.arg1 then
				info.checked = 1
			else
				info.checked = nil
			end
			info.keepShownOnClick = nil
			UIDropDownMenu_AddButton(info)
		end
	end
	DrainSouler_InterfaceOptions_TickSoundText:SetText(sounds[DrainSouler_Options.TickSound].name)
	UIDropDownMenu_SetWidth(DrainSouler_InterfaceOptions_TickSound, width+50)
	UIDropDownMenu_EnableDropDown(DrainSouler_InterfaceOptions_TickSound)
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:CreateFrames()
	-- Main DrainSouler Frame
	local frame = CreateFrame("Frame", "DrainSouler_Frame")
	frame:SetClampedToScreen(true)
	frame:SetClampRectInsets(0, 80, 0, -20)
	frame:SetMovable(true)
	frame:SetPoint("CENTER", UIParent, 0, 200)
	frame:SetWidth(1)
	frame:SetHeight(1)
	frame:SetScale(1)
	frame:Hide()

	local icon = CreateFrame("Button", "DrainSouler_Button_Icon", DrainSouler_Frame)
	icon:SetFrameLevel(DrainSouler_Frame:GetFrameLevel()+1)
	icon:SetWidth(20)
	icon:SetHeight(20)
	icon:ClearAllPoints()
	icon:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 0, 0)
	local background = icon:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(icon)
	background:SetTexture(0, 0, 0, 1)
	local texture = icon:CreateTexture(nil, "BACKGROUND")
	texture:SetWidth(18)
	texture:SetHeight(18)
	texture:SetPoint("TOPLEFT", "DrainSouler_Button_Icon", "TOPLEFT", 1, -1)
	texture:SetTexture(DrainSoulIcon)

	local HP = CreateFrame("Button", "DrainSouler_Button_HP", DrainSouler_Frame)
	HP:SetFrameLevel(DrainSouler_Frame:GetFrameLevel()+1)
	HP:SetWidth(60)
	HP:SetHeight(10)
	HP:ClearAllPoints()
	HP:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 20, 0)
	local background = HP:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(HP)
	background:SetTexture(0, 0, 0, 1)
	local text = HP:CreateFontString("DrainSouler_Text_HP", "ARTWORK", "GameFontWhiteTiny")
	text:SetAllPoints(HP)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("MIDDLE")

	local DMG = CreateFrame("Button", "DrainSouler_Button_DMG", DrainSouler_Frame)
	DMG:SetFrameLevel(DrainSouler_Frame:GetFrameLevel()+1)
	DMG:SetWidth(60)
	DMG:SetHeight(10)
	DMG:ClearAllPoints()
	DMG:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 20, -10)
	local background = DMG:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(DMG)
	background:SetTexture(0, 0, 0, 1)
	local text = DMG:CreateFontString("DrainSouler_Text_DMG", "ARTWORK", "GameFontWhiteTiny")
	text:SetAllPoints(DMG)
	text:SetJustifyH("CENTER")
	text:SetJustifyV("MIDDLE")

	local TickTimer = CreateFrame("Button", "DrainSouler_Button_TickTimer", DrainSouler_Frame)
	TickTimer:SetFrameLevel(DrainSouler_Frame:GetFrameLevel()+1)
	TickTimer:SetWidth(60)
	TickTimer:SetHeight(10)
	TickTimer:ClearAllPoints()
	TickTimer:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 20, -10)
	local texture = TickTimer:CreateTexture("DrainSouler_Texture_TickTimer", "ARTWORK")
	texture:SetWidth(0.01)
	texture:SetHeight(6)
	texture:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 20, -12)
	texture:SetTexture(0.12, 0.34, 0.45, 1)

	local Tick = CreateFrame("Button", "DrainSouler_Button_Tick", DrainSouler_Frame)
	Tick:SetFrameLevel(DrainSouler_Frame:GetFrameLevel()+2)
	Tick:SetWidth(20)
	Tick:SetHeight(20)
	Tick:ClearAllPoints()
	Tick:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 20, 0)
	local background = Tick:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(Tick)
	background:SetTexture(1, 1, 1, 0)
	local text = Tick:CreateFontString("DrainSouler_Text_Tick", "ARTWORK", "GameFontHighlightLarge")
	text:SetAllPoints(Tick)
	text:SetJustifyH("LEFT")
	text:SetJustifyV("MIDDLE")

	-- Config Mode / FirstTime use
	local frame = CreateFrame("Frame", "DrainSouler_ConfigModeOptions")
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:SetScale(0.75)
	frame:SetWidth(360)
	frame:SetHeight(460)
	frame:ClearAllPoints()
	frame:SetPoint("TOPLEFT", DrainSouler_Frame, "TOPLEFT", 0, -45)
	frame:Hide()
	local background = frame:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(frame)
	background:SetTexture(0, 0, 0, 1)

	local position = CreateFrame("Button", nil, DrainSouler_ConfigModeOptions)
	position:SetWidth(24)
	position:SetHeight(24)
	position:SetPoint("TOPRIGHT", "DrainSouler_ConfigModeOptions", "TOPLEFT", 0, 0)
	local background = position:CreateTexture(nil, "BACKGROUND")
	background:SetAllPoints(position)
	background:SetTexture(0, 0, 0, 1)
	local texture = position:CreateTexture(nil, "BACKGROUND")
	texture:SetWidth(20)
	texture:SetHeight(20)
	texture:SetPoint("CENTER", position, "CENTER", 0, 0)
	texture:SetTexture("Interface\\Buttons\\UI-Panel-CollapseButton-Up")
	texture:SetTexCoord(6/32, 25/32, 7/32, 25/32)

	local posi
	position:SetScript("OnEnter", function()
		texture:SetWidth(18)
		texture:SetHeight(18)
	end)
	position:SetScript("OnLeave", function()
		texture:SetWidth(20)
		texture:SetHeight(20)
	end)
	position:SetScript("OnClick", function()
		if not posi then
			frame:ClearAllPoints()
			frame:SetPoint("BOTTOMLEFT", "DrainSouler_Frame", "TOPLEFT", 0, 19)
			position:ClearAllPoints()
			position:SetPoint("BOTTOMRIGHT", "DrainSouler_ConfigModeOptions", "BOTTOMLEFT", 0, 0)
			texture:SetTexture("Interface\\Buttons\\UI-Panel-ExpandButton-Up")
			posi = true
		else
			frame:ClearAllPoints()
			frame:SetPoint("TOPLEFT", "DrainSouler_Frame", "TOPLEFT", 0, -45)
			position:ClearAllPoints()
			position:SetPoint("TOPRIGHT", "DrainSouler_ConfigModeOptions", "TOPLEFT", 0, 0)
			texture:SetTexture("Interface\\Buttons\\UI-Panel-CollapseButton-Up")
			posi = nil
		end
	end)

	DrainSouler:CreateOptions(2)

	-- Config Mode / FirstTime use width
	local width = 0
	local swidth = 0
	swidth = DrainSouler_ConfigModeOptions_minHP_description:GetStringWidth()
	if swidth > width then width = swidth end
	swidth = DrainSouler_ConfigModeOptions_minHPP_description:GetStringWidth()
	if swidth > width then width = swidth end
	swidth = DrainSouler_ConfigModeOptions_TickSound_description:GetStringWidth()
	if swidth > width then width = swidth end
	swidth = DrainSouler_ConfigModeOptions_CloseConfiguration_description:GetStringWidth()
	if swidth > width then width = swidth end
	frame:SetWidth(width+50)

	-- setup scripts for both DrainSouler_InterfaceOptions and DrainSouler_ConfigModeOptions
	DrainSouler:CreateOptions_SetupScripts()
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:DisableMovement()
	DrainSouler_Button_Icon:SetScript("OnMouseDown", nil)
	DrainSouler_Button_Icon:SetScript("OnMouseUp", nil)
	DrainSouler_Button_Icon:SetScript("OnHide", nil)
	DrainSouler_Button_Icon:EnableMouse(false)
	DrainSouler_Button_HP:SetScript("OnMouseDown", nil)
	DrainSouler_Button_HP:SetScript("OnMouseUp", nil)
	DrainSouler_Button_HP:SetScript("OnHide", nil)
	DrainSouler_Button_HP:EnableMouse(false)
	DrainSouler_Button_DMG:SetScript("OnMouseDown", nil)
	DrainSouler_Button_DMG:SetScript("OnMouseUp", nil)
	DrainSouler_Button_DMG:SetScript("OnHide", nil)
	DrainSouler_Button_DMG:EnableMouse(false)
	DrainSouler_Button_TickTimer:SetScript("OnMouseDown", nil)
	DrainSouler_Button_TickTimer:SetScript("OnMouseUp", nil)
	DrainSouler_Button_TickTimer:SetScript("OnHide", nil)
	DrainSouler_Button_TickTimer:EnableMouse(false)
	DrainSouler_Button_Tick:SetScript("OnMouseDown", nil)
	DrainSouler_Button_Tick:SetScript("OnMouseUp", nil)
	DrainSouler_Button_Tick:SetScript("OnHide", nil)
	DrainSouler_Button_Tick:EnableMouse(false)
end

function DrainSouler:EnableMovement()
	DrainSouler_Button_Icon:SetScript("OnMouseDown", OnMouseDown)
	DrainSouler_Button_Icon:SetScript("OnMouseUp", OnMouseUp)
	DrainSouler_Button_Icon:SetScript("OnHide", OnMouseUp)
	DrainSouler_Button_Icon:EnableMouse(true)
	DrainSouler_Button_HP:SetScript("OnMouseDown", OnMouseDown)
	DrainSouler_Button_HP:SetScript("OnMouseUp", OnMouseUp)
	DrainSouler_Button_HP:SetScript("OnHide", OnMouseUp)
	DrainSouler_Button_HP:EnableMouse(true)
	DrainSouler_Button_DMG:SetScript("OnMouseDown", OnMouseDown)
	DrainSouler_Button_DMG:SetScript("OnMouseUp", OnMouseUp)
	DrainSouler_Button_DMG:SetScript("OnHide", OnMouseUp)
	DrainSouler_Button_DMG:EnableMouse(true)
	DrainSouler_Button_TickTimer:SetScript("OnMouseDown", OnMouseDown)
	DrainSouler_Button_TickTimer:SetScript("OnMouseUp", OnMouseUp)
	DrainSouler_Button_TickTimer:SetScript("OnHide", OnMouseUp)
	DrainSouler_Button_TickTimer:EnableMouse(true)
	DrainSouler_Button_Tick:SetScript("OnMouseDown", OnMouseDown)
	DrainSouler_Button_Tick:SetScript("OnMouseUp", OnMouseUp)
	DrainSouler_Button_Tick:SetScript("OnHide", OnMouseUp)
	DrainSouler_Button_Tick:EnableMouse(true)
end

function DrainSouler:SetupAlpha()
	DrainSouler_Button_Icon:SetAlpha(DrainSouler_Options.Alpha)
	DrainSouler_Button_HP:SetAlpha(DrainSouler_Options.Alpha)
	DrainSouler_Button_DMG:SetAlpha(DrainSouler_Options.Alpha)
	DrainSouler_Button_TickTimer:SetAlpha(DrainSouler_Options.Alpha)
	DrainSouler_Button_Tick:SetAlpha(DrainSouler_Options.Alpha)
end

function DrainSouler:SetupSize()
	DrainSouler_Button_Icon:SetScale(DrainSouler_Options.Size)
	DrainSouler_Button_HP:SetScale(DrainSouler_Options.Size)
	DrainSouler_Button_DMG:SetScale(DrainSouler_Options.Size)
	DrainSouler_Button_TickTimer:SetScale(DrainSouler_Options.Size)
	DrainSouler_Button_Tick:SetScale(DrainSouler_Options.Size)
end

function DrainSouler:EnableConfigMode()
	DrainSouler_Frame:Show()
	DrainSouler_ConfigModeOptions:Show()
	DrainSouler_InterfaceOptions_ConfigMode:Disable()
	DrainSouler_Button_Icon:Show()
	
	DrainSouler_Text_HP:SetText("HP%")
	DrainSouler_Text_DMG:SetText("DMG")
	DrainSouler_Text_Tick:SetText("X")

	DrainSouler:UnregisterEvent("PLAYER_TARGET_CHANGED")
	DrainSouler:UnregisterEvent("UNIT_SPELLCAST_SUCCEEDED")
	DrainSouler:UnregisterEvent("UNIT_SPELLCAST_CHANNEL_UPDATE")
	DrainSouler:UnregisterEvent("UNIT_SPELLCAST_CHANNEL_STOP")
	DrainSouler:UnregisterEvent("PLAYER_REGEN_DISABLED")
	DrainSouler:UnregisterEvent("PLAYER_REGEN_ENABLED")
end

function DrainSouler:DisableConfigMode()
	DrainSouler_InterfaceOptions_ConfigMode:Enable()
	DrainSouler_ConfigModeOptions:Hide()

	DrainSouler_Text_HP:SetText("")
	DrainSouler_Text_DMG:SetText("")
	DrainSouler_Text_Tick:SetText("")

	if InCombatLockdown() then
		inCombat = true
	else
		inCombat = false
	end

	DrainSouler:RegisterEvent("PLAYER_TARGET_CHANGED")
	DrainSouler:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED")
	DrainSouler:RegisterEvent("UNIT_SPELLCAST_CHANNEL_UPDATE")
	DrainSouler:RegisterEvent("UNIT_SPELLCAST_CHANNEL_STOP")
	DrainSouler:RegisterEvent("PLAYER_REGEN_DISABLED")
	DrainSouler:RegisterEvent("PLAYER_REGEN_ENABLED")

	TargetUnitCheck()
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
function DrainSouler:Init()
	if DrainSouler_Options.Lock then
		DrainSouler:DisableMovement()
		DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(0, 0, 0, 1)
	else
		DrainSouler:EnableMovement()
		DrainSouler_ConfigModeOptions_MoveNote:SetTextColor(1, 1, 0.5, 1)
	end

	DrainSouler:SetupAlpha()
	DrainSouler:SetupSize()

	if DrainSouler_Options.posX then
		DrainSouler_Frame:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", DrainSouler_Options.posX, DrainSouler_Options.posY)
	end

	if DrainSouler_Options.configMode then
		DrainSouler:EnableConfigMode()
	else
		DrainSouler:DisableConfigMode()
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

-- ---------------------------------------------------------------------------------------------------------------------
local function OnEvent(self, event, ...)
	if event == "UNIT_HEALTH" then
		if arg1 == "target" then 
			CheckHealth()
		end
	elseif event == "PLAYER_TARGET_CHANGED" then
		TargetUnitCheck()
	elseif event == "UNIT_SPELLCAST_SUCCEEDED" then
		if arg1 == "player" and arg2 == DrainSoulName then
			local _, _, _, _, startTime, endTime = UnitChannelInfo("player")
			if startTime and endTime then
				DrainSoulIsActive = true
				DrainSouler:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
				numTicks = 5
				DrainSoulCurrentDuration = endTime-startTime
				DrainSoulCurrentStart = startTime
				DrainSouler_Button_TickTimer:Show()
				DrainSouler_Button_TickTimer:SetScript("OnUpdate", TickTimer)
			end
		end
	elseif event == "UNIT_SPELLCAST_CHANNEL_UPDATE" then
		if arg1 == "player" and arg2 == DrainSoulName then
			local _, _, _, _, _, endTime = UnitChannelInfo("player")
			numTicks = 4
			if endTime then
				DrainSoulCurrentDuration = endTime-DrainSoulCurrentStart
			end
		end
	elseif event == "UNIT_SPELLCAST_CHANNEL_STOP" then
		if arg1 == "player" and arg2 == DrainSoulName then
			DrainSouler_Button_TickTimer:SetScript("OnUpdate", nil)
			DrainSoulCurrentDuration = nil
			DrainSoulCurrentTick = 0
			DrainSoulIsActive = nil
			DrainSouler_Text_Tick:SetText("")
			DrainSouler_Text_DMG:SetText("")
			DrainSouler_Button_TickTimer:Hide()
			DrainSouler:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
		end
	elseif event == "COMBAT_LOG_EVENT_UNFILTERED" then
		if arg3 ~= PlayerGUID then return end
		if arg10 == DrainSoulName and arg2 == "SPELL_PERIODIC_DAMAGE" then
			local _, _, _, _, _, endTime = UnitChannelInfo("player")
			if endTime then
				DrainSoulCurrentStart = GetTime()*1000
				DrainSoulCurrentDuration = endTime-DrainSoulCurrentStart
			end
			DrainSoulCurrentTick = DrainSoulCurrentTick + 1
			if DrainSouler_Options.TickSound > 1 then
				PlaySoundFile(sounds[DrainSouler_Options.TickSound].path)
			end
			DrainSouler_Text_Tick:SetText(DrainSoulCurrentTick)
			DrainSouler_Text_DMG:SetText(arg12)
		end
	elseif event == "PLAYER_REGEN_DISABLED" then
		inCombat = true
		TargetUnitCheck()
	elseif event == "PLAYER_REGEN_ENABLED" then
		inCombat = false
		TargetUnitCheck()
	elseif event == "PLAYER_LOGIN" then
		DrainSouler:InitOptions()
		DrainSouler:CreateInterfaceOptions()
		DrainSouler:CreateFrames()
		DrainSouler:Init()
		PlayerGUID = UnitGUID("player")
		DrainSouler:UnregisterEvent("PLAYER_LOGIN")
	end
end
-- ---------------------------------------------------------------------------------------------------------------------

DrainSouler:RegisterEvent("PLAYER_LOGIN")
DrainSouler:SetScript("OnEvent", OnEvent)